@@ -3,7 +3,7 @@ import * as helper from "../__fixtures__/test-helper";
 helper.createSuite("Events", (test, cb) =>
     helper.writeToParser(
         helper.getEventCollector(cb),
-        test.options.parser,
+        test.options?.parser,
         test.html
     )
 );
